type QualityPreset = 'low' | 'medium' | 'high' | 'lossless';
interface VideoConfig {
    codec?: 'avc' | 'hevc' | 'vp9' | 'vp8' | 'av1';
    bitrate?: number;
    hardwareAcceleration?: 'no-preference' | 'prefer-hardware' | 'prefer-software';
    latencyMode?: 'quality' | 'realtime';
    keyFrameInterval?: number;
}
interface AudioConfig {
    codec?: 'aac' | 'opus';
    bitrate?: number;
    sampleRate?: number;
    channels?: number;
    bitrateMode?: 'constant' | 'variable';
}
interface ProgressInfo {
    percent: number;
    processedFrames: number;
    totalFrames?: number;
    fps: number;
    stage: string;
    estimatedRemainingMs?: number;
}
interface EncodeOptions {
    width?: number;
    height?: number;
    frameRate?: number;
    quality?: QualityPreset;
    video?: VideoConfig | false;
    audio?: AudioConfig | false;
    container?: 'mp4' | 'webm';
    firstTimestampBehavior?: "offset" | "strict";
    latencyMode?: "quality" | "realtime";
    maxVideoQueueSize?: number;
    maxAudioQueueSize?: number;
    backpressureStrategy?: "drop" | "wait";
    onProgress?: (progress: ProgressInfo) => void;
    onError?: (error: EncodeError) => void;
}
type EncodeErrorType = 'not-supported' | 'initialization-failed' | 'configuration-error' | 'invalid-input' | 'encoding-failed' | 'video-encoding-error' | 'audio-encoding-error' | 'muxing-failed' | 'cancelled' | 'timeout' | 'worker-error' | 'filesystem-error' | 'unknown';
declare class EncodeError extends Error {
    type: EncodeErrorType;
    cause?: unknown;
    constructor(type: EncodeErrorType, message: string, cause?: unknown);
}

/**
 * Encode capability verification
 */

/**
 * Verify encode capability
 *
 * @param options Encode options
 * @returns Whether encoding is possible
 */
declare function canEncode(options?: EncodeOptions): Promise<boolean>;
/**
 * Dynamically generate AVC (H.264) codec string
 * Uses same logic as encoder-worker.ts
 */
declare function generateAvcCodecString(width: number, height: number, frameRate: number, profile?: "high" | "main" | "baseline"): string;
/**
 * Try multiple AVC profiles and return the first supported one
 */
declare function generateSupportedAvcCodecString(width: number, height: number, frameRate: number, bitrate: number, preferredProfile?: "high" | "main" | "baseline"): Promise<string | null>;
/**
 * Check support for specific codec and profile (for advanced users)
 */
declare function canEncodeWithProfile(videoCodec: string, audioCodec?: string, profile?: {
    width: number;
    height: number;
    framerate: number;
    videoBitrate: number;
    audioBitrate?: number;
}): Promise<{
    video: boolean;
    audio: boolean;
    overall: boolean;
}>;

export { canEncode, canEncodeWithProfile, generateAvcCodecString, generateSupportedAvcCodecString };
